pynrc.nb\_funcs
===============

.. automodule:: pynrc.nb_funcs

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
      :toctree:
   
      average_slopes
      disk_rim_model
      do_contrast
      do_gen_hdus
      do_opt
      do_plot_contrasts
      do_plot_contrasts2
      do_sat_levels
      make_key
      model_info
      obs_optimize
      obs_wfe
      planet_mags
      plot_contrasts
      plot_contrasts_mjup
      plot_hdulist
      plot_images
      plot_images_swlw
      plot_planet_patches
      plot_spectrum
      update_yscale
   
   

   
   
   

   
   
   



